macro_rules! progress_inline {
($($arg:tt)*) => { ... };
}Expand description
Print an inline progress message to stderr without a newline (suppressed with --quiet).
Usage: progress_inline!(" resolving ...");
macro_rules! progress_inline {
($($arg:tt)*) => { ... };
}Print an inline progress message to stderr without a newline (suppressed with --quiet).
Usage: progress_inline!(" resolving ...");